@@ -2,9 +2,9 @@
  * 
  * fitqtl_hk.h
  *
- * copyright (c) 2007-2013, Karl W Broman
+ * copyright (c) 2007-2014, Karl W Broman
  *
- * last modified Feb, 2013
+ * last modified Mar, 2014
  * first written Nov, 2007
  *
  *     This program is free software; you can redistribute it and/or
@@ -28,11 +28,11 @@
  *
  **********************************************************************/
 void R_fitqtl_hk(int *n_ind, int *n_qtl, int *n_gen, 
-		 double *genoprob, int *n_cov, double *cov, int *model, 
-		 int *n_int, double *pheno, int *get_ests,
-		  /* return variables */
-		 double *lod, int *df, double *ests, double *ests_covar,
-		 double *design_mat, int *matrix_rank);
+                 double *genoprob, int *n_cov, double *cov, int *model, 
+                 int *n_int, double *pheno, int *get_ests,
+                 /* return variables */
+                 double *lod, int *df, double *ests, double *ests_covar,
+                 double *design_mat, int *matrix_rank, double *residuals);
 
 /**********************************************************************
  * 
@@ -70,19 +70,21 @@ void R_fitqtl_hk(int *n_ind, int *n_qtl, int *n_gen,
  *
  * matrix_rank  On return, rank of design matrix
  *
+ * residuals    On return, the residuals from the fit
+ *
  **********************************************************************/
 
 void fitqtl_hk(int n_ind, int n_qtl, int *n_gen, double ***Genoprob,
-	       double **Cov, int n_cov, 
-	       int *model, int n_int, double *pheno, int get_ests,
-	       double *lod, int *df, double *ests, double *ests_covar,
-	       double *design_mat, int *matrix_rank); 
+               double **Cov, int n_cov, 
+               int *model, int n_int, double *pheno, int get_ests,
+               double *lod, int *df, double *ests, double *ests_covar,
+               double *design_mat, int *matrix_rank, double *residuals); 
 
 /* galtRssHK - calculate RSS for full model by Haley-Knott regression */
 double galtRssHK(double *pheno, int n_ind, int *n_gen, int n_qtl, 
-		 double ***Genoprob, double **Cov, int n_cov, int *model, 
-		 int n_int, double *dwork, int *iwork, int sizefull,
-		 int get_ests, double *ests, double **Ests_covar,
-		 double *designmat, int *matrix_rank);
+                 double ***Genoprob, double **Cov, int n_cov, int *model, 
+                 int n_int, double *dwork, int *iwork, int sizefull,
+                 int get_ests, double *ests, double **Ests_covar,
+                 double *designmat, int *matrix_rank, double *residuals);
 
 /* end of fitqtl_hk.h */
